@@ -6,7 +6,11 @@ castable_packages = {
     "activity": "android.app.Activity",
     "context": "android.content.Context",
     "downloadManager": "android.app.DownloadManager",
-    "charSequence": "java.lang.CharSequence"
+    "charSequence": "java.lang.CharSequence",
+    "bitmapDrawable": "android.graphics.drawable.BitmapDrawable",
+    "adaptiveIconDrawable": "android.graphics.drawable.AdaptiveIconDrawable",
+    "audioManager": "android.media.AudioManager",
+    "uri": "android.net.Uri"
 }
 
 
